==> web2sms_0.1.1-1.tar.gz: web2sms-0.1.1/src/providers/contacts_windows.cpp <==
/*
 *
 *  Copyright (c) 2010 Christoph Keller <gri@nospam@not-censored.com>
 *
 *  This file is part of Web2SMS.
 *
 *  Web2SMS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Web2SMS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Web2SMS. If not, see <http://www.gnu.org/licenses/>
 *
 */

// Local includes
#include "contacts.h"

// Global includes
#include <QtGui/QMessageBox>
#include <QtGui/QApplication>

extern "C"
{

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

void PROVIDERS_API init_contacts()
{
}

//////////////////////////////////////////////////////////////////////////

void PROVIDERS_API deinit_contacts()
{
}

//////////////////////////////////////////////////////////////////////////

int PROVIDERS_API get_contact_for_sms(const QString* dialogTitle, ContactInfoList* contacts)
{
  Q_UNUSED(dialogTitle);

  ContactInfo info;
  info.setName( "Test Dummy" );
  info.setNumber( "+4900000000" );
  info.setUniqueId( "unique_id_1" );

  contacts->append( info );

  info.setName( "dummy 2" );
  info.setNumber( "+491223123" );
  info.setUniqueId( "unique_id_2" );

  contacts->append( info );

  return TRUE;
}

//////////////////////////////////////////////////////////////////////////

int PROVIDERS_API add_to_sent_sms(const QString* name, const QString* number, const QString* uid, const QString* message)
{
  Q_UNUSED(name);
  Q_UNUSED(number);
  Q_UNUSED(uid);
  Q_UNUSED(message);

  return FALSE;
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

} // extern "C"

==> web2sms_0.1.2-0.tar.gz: web2sms-0.1.2/src/providers/contacts_windows.cpp <==
/*
 *
 *  Copyright (c) 2010 Christoph Keller <gri@nospam@not-censored.com>
 *
 *  This file is part of Web2SMS.
 *
 *  Web2SMS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Web2SMS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Web2SMS. If not, see <http://www.gnu.org/licenses/>
 *
 */

// Local includes
#include "contacts.h"

// Global includes
#include <QtGui/QMessageBox>
#include <QtGui/QApplication>

extern "C"
{

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

void PROVIDERS_API init_contacts()
{
}

//////////////////////////////////////////////////////////////////////////

void PROVIDERS_API deinit_contacts()
{
}

//////////////////////////////////////////////////////////////////////////

int PROVIDERS_API get_contact_for_sms(const QString* dialogTitle, ContactInfoList* contacts)
{
  Q_UNUSED(dialogTitle);

  ContactInfo info;
  info.setName( "Test Dummy" );
  info.setNumber( "00491747365352" );
  info.setUniqueId( "unique_id_1" );

  contacts->append( info );

  info.setName( "dummy 2" );
  info.setNumber( "+491223123" );
  info.setUniqueId( "unique_id_2" );

  contacts->append( info );

  return TRUE;
}

//////////////////////////////////////////////////////////////////////////

int PROVIDERS_API add_to_sent_sms(const QString* name, const QString* number, const QString* uid, const QString* message)
{
  Q_UNUSED(name);
  Q_UNUSED(number);
  Q_UNUSED(uid);
  Q_UNUSED(message);

  return FALSE;
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

} // extern "C"
